#[non_exhaustive]pub enum Request<'a> {
Destroy,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Destroy
destroy the input timestamps object
Informs the server that the client will no longer be using this protocol object. After the server processes the request, no more timestamp events will be emitted.
This is a destructor, once sent this object cannot be used any longer.
Implementations